@@ -7,7 +7,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2004  LUGFI
+ * Copyright (C) 2003,2005  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -100,7 +100,13 @@ dialog_about (void)
 		NULL
 	};
 
-	const gchar *copy = _("(c) 2003-2004 LUGFi\n(c) 1999-2001 Richard Hult");
+	const char *docs[] = {
+		"Ricardo Markiewicz <rmarkie@fi.uba.ar> (es)",
+		"Jordi Mallach <tradgnome@softcatala.net> (ca)",
+		NULL
+	};
+
+	const gchar *copy = _("(c) 2003-2005 LUGFi\n(c) 1999-2001 Richard Hult");
 
 	/* Allow only one about box at a time. */
 	if (about){
@@ -117,7 +123,7 @@ dialog_about (void)
 		copy,
 		_("Schematic capture and circuit simulation.\n"),
 		authors,
-		NULL, NULL,
+		docs, NULL,
 		logo);
 
 	g_signal_connect (
