@@ -4,7 +4,7 @@
  * @author Ricardo Markiewicz <rmarkie@fi.uba.ar>
  * @author Andres de Barbara <adebarbara@fi.uba.ar>
  *
- * @date   1999-2001,2003-2004
+ * @date   1999-2001,2003-2005
  *
  * @brief Oregano, a tool for schematic capture and simulation of electrical
  * circuits.
@@ -13,7 +13,7 @@
  */
 /*
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2004  LUGFI
+ * Copyright (C) 2003,2005  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -175,7 +175,7 @@ main (int argc, char **argv)
 
 				gtk_widget_show_all (schematic_view->toplevel);
 				schematic_set_filename (new_schematic, fname);
-				// schematic_set_title (new_schematic, fname);
+				schematic_set_title (new_schematic, g_path_get_basename(fname));
 
 				 /* Show something */
 				while (gtk_events_pending ())
@@ -208,4 +208,3 @@ main (int argc, char **argv)
 	gnome_config_drop_all ();
 	return 0;
 }
-
