@@ -10,7 +10,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2004  LUGFI
+ * Copyright (C) 2003,2005  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -263,7 +263,7 @@ foreach_model_write (char *model, gpointer user_data, FILE *f)
 {
 	char *str, *tmp1, *tmp2;
 
-	tmp1 = g_build_filename (OREGANO_MODELDIR, model);
+	tmp1 = g_build_filename (OREGANO_MODELDIR, model, NULL);
 	tmp2 = g_strconcat (tmp1, ".model", NULL);
 
 	str = g_strdup_printf (".include %s\n", tmp2);
