@@ -11,7 +11,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2004  LUGFI
+ * Copyright (C) 2003,2005  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -88,7 +88,7 @@ static GObjectClass *parent_class = NULL;
 GType
 node_store_get_type (void)
 {
-	static guint node_store_type = 0;
+	static GType node_store_type = 0;
 
 	if (!node_store_type) {
 		static const GTypeInfo node_store_info = {
