@@ -10,7 +10,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2004  LUGFI
+ * Copyright (C) 2003,2005  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -67,7 +67,7 @@ oregano_config_load (void)
 	/* Let's deal with first use -I don't like this- */
 
 	if (!oregano.simexec)
-		oregano.simexec = g_strdup ("oregano_parser.pl");
+		oregano.simexec = g_strdup ("oregano_parser");
 	if (!oregano.simtype)
 		oregano.simtype = g_strdup ("gnucap");
 }
