@@ -10,7 +10,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2004  LUGFI
+ * Copyright (C) 2003,2005  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -42,30 +42,30 @@
  * @return the name of a macro variable
  */
 static char *get_macro_name (const char *str, char **cls1,
-	char **cls2, int *sz)
+	char **cls2, unsigned int *sz)
 {
-	char tmp[512], separators[] = { ",.;/|()" };
-	char *id;
+	char separators[] = { ",.;/|()" };
+	GString *out;
 	const char *q, *qend;
-	char *qn, *csep = NULL;
+	char *csep = NULL;
 	size_t sln;
 	int rc = 0;
+	char *ret;
 
 	sln = strlen (str) + 1;
 	*sz = 0;
-	*cls1 = *cls2 = 0;
+	*cls1 = *cls2 = NULL;
 	qend = str + sln;
-	id = g_malloc0 (sln);
+	out = g_string_sized_new (sln);
 
 	/* Get the name */
-	for (q = str, qn = id; *q && *q != ' ' &&
-		     !(csep = strchr (separators, *q)); q++) {
+	for (q = str; (*q) && (*q != ' ') && !(csep = strchr (separators, *q)); q++) {
 		if ( q > qend ) {
 			g_warning ("Expand macro error.");
 			rc = 1;
 			break;
 		}
-		*qn++ = *q;
+		out = g_string_append_c (out, *q);
 	}
 
 	/* if error found, return here */
@@ -73,44 +73,55 @@ static char *get_macro_name (const char *str, char **cls1,
 		goto error;
 
 	/* Look for conditional clauses */
-	*qn = 0;
 	if (csep) {
 		/* get the first one */
+		GString *aux;
 		q++; /* skip the separator and store the clause in tmp */
-		for (qn = tmp; *q && *q != *csep; q++)
-			*qn++ = *q;
+		aux = g_string_new ("");
+		for (; (*q) && (*q != *csep); q++)
+			g_string_append_c (aux, *q);
 
-		if (!*q)
+		if (!*q) {
+			g_string_free (aux, TRUE);
 			goto error;
+		}
 
-		*qn = 0;
-		*cls1 = g_strdup(tmp);
+		*cls1 = aux->str;
 		q++; /* skip the end-of-clause separator */
+		g_string_free (aux, FALSE);
 
 		/* Check for the second one */
-		if ( *q && (csep = strchr (separators, *q))) {
+		if ( (*q) && (csep = strchr (separators, *q))) {
 			q++; /* skip the separator and store in tmp*/
-			for (qn = tmp; *q && *q != *csep; q++)
-				*qn++ = *q;
+			aux = g_string_new ("");
+			for (; (*q) && (*q != *csep); q++)
+				g_string_append_c (aux, *q);
 
-			if (!*q) {
+			if (!(*q)) {
 				g_free (*cls1);
-				*cls1 = 0;
+				*cls1 = NULL;
 				goto error;
 			}
 
-			*qn = 0;
-			*cls2 = g_strdup (tmp);
+			*cls2 = aux->str;
 			q++; /* skip the end-of-clause separator */
+			g_string_free (aux, FALSE);
 		}
 	}
 
-	*sz = (int) (q - str);
-	return id;
+	*sz = out->len;
+	ret = NULL;
+	if (out->len > 0) {
+		out = g_string_append_c (out, '\0');
+		ret = g_strdup (out->str);
+	}
+	g_string_free (out, TRUE);
+
+	return ret;
 
  error:
-	g_free (id);
-	return 0;
+	g_string_free (out, TRUE);
+	return NULL;
 }
 
 char *
@@ -118,16 +129,17 @@ part_property_expand_macros (Part *part, char *string)
 {
 	static char mcode[] = {"@?~#&"};
 	char *value;
-	char *tmp0, *temp, *pbuf, *qn, *q0, *qend, *t0;
+	char *tmp0, *temp, *qn, *q0, *qend, *t0;
 	char *cls1, *cls2;
-	char buffer[512];
+	GString *out;
 	size_t sln;
+	char *ret;
 
 	g_return_val_if_fail (part != NULL, NULL);
 	g_return_val_if_fail (IS_PART (part), NULL);
 	g_return_val_if_fail (string != NULL, NULL);
 
-	cls1 = cls2 = q0 = 0;
+	cls1 = cls2 = q0 = NULL;
 	/* Rules:
 	   @<id>             value of <id>. If no value, error
 	   &<id>             value of <id> if <id> is defined
@@ -147,30 +159,31 @@ part_property_expand_macros (Part *part, char *string)
 	   V^@refdes %+ %- SIN(@offset @ampl @freq 0 0)
 	   ?DC|DC @DC|
 	*/
-	pbuf = buffer;
 	tmp0 = temp = g_strdup (string);
 	qend = temp + strlen (temp);
 
-	for (pbuf = buffer, temp = string; *temp;) {
+	out = g_string_new ("");
+
+	for (temp = string; *temp;) {
 		/*
 		 * Look for any of the macro char codes.
 		 */
 		if (strchr (mcode, *temp)) {
 			qn = get_macro_name (temp + 1, &cls1, &cls2, &sln);
-			if (qn == 0)
-				return 0;
+			if (qn == NULL)
+				return NULL;
 			value = part_get_property (part, qn);
 			if ((*temp == '@' || *temp == '&') && value) {
-				pbuf += sprintf (pbuf, "%s", value);
+				out = g_string_append (out, value);
 			} else if (*temp =='&' && !value) {
 				g_warning ( "expand macro error: macro %s undefined", qn);
 				g_free (qn);
-				return 0;
+				return NULL;
 			} else if (*temp == '?' || *temp == '~') {
-				if (cls1 == 0) {
+				if (cls1 == NULL) {
 					g_warning ("error in template: %s", temp);
 					g_free (qn);
-					return 0;
+					return NULL;
 				}
 				q0 = (value
 					  ? (*temp == '?' ? cls1 : cls2)
@@ -181,9 +194,10 @@ part_property_expand_macros (Part *part, char *string)
 					if (!t0) {
 						g_warning ( "error in template: %s", temp);
 						g_free (qn);
+					} else {
+						out = g_string_append (out, t0);
+						g_free (t0);
 					}
-					pbuf += sprintf (pbuf, "%s", t0);
-					g_free (t0);
 				}
 			} else if (*temp=='#') {
 				if (value) {
@@ -191,35 +205,49 @@ part_property_expand_macros (Part *part, char *string)
 					if (!t0) {
 						g_warning ( "error in template: %s", temp);
 						g_free (qn);
+					} else {
+						out = g_string_append (out, t0);
+						g_free (t0);
 					}
-					pbuf += sprintf (pbuf, "%s", t0);
-					g_free (t0);
 				} else
 					*(temp + sln) = 0;
 			}
-			temp += 1 + sln;
-			g_free (qn);
-			g_free (cls1);
-			g_free (cls2);
+			temp += 1;
+			temp += sln;
+			if (qn) g_free (qn);
+			if (cls1) g_free (cls1);
+			if (cls2) g_free (cls2);
 		} else {
 			if ( *temp== '\\' ) {
 				temp++;
 				switch (*temp) {
-				case 'n': *pbuf++ = '\n'; break;
-				case 't': *pbuf++ = '\t'; break;
-				case 'r': *pbuf++ = '\r'; break;
-				case 'f': *pbuf++ = '\f'; break;
+				case 'n':
+					out = g_string_append_c (out, '\n');
+				break;
+				case 't':
+					out = g_string_append_c (out, '\t');
+				break;
+				case 'r':
+					out = g_string_append_c (out, '\r');
+				break;
+				case 'f':
+					out = g_string_append_c (out, '\f');
 				}
 				temp++;
-			} else
-				*pbuf++ = *temp++;
+			} else {
+				out = g_string_append_c (out, *temp);
+				temp++;
+			}
 		}
 	}
 
-	g_free (tmp0);
-	*pbuf = 0;
+	if (tmp0) g_free (tmp0);
 
-	return g_strdup (buffer);
+	out = g_string_append_c (out, '\0');
+	ret = g_strdup (out->str);
+	g_string_free (out, TRUE);
+
+	return ret;
 }
 
 
