@@ -10,7 +10,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001	Richard Hult
- * Copyright (C) 2003,2004	LUGFI
+ * Copyright (C) 2003,2005	LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -160,7 +160,7 @@ static GnomeUIInfo plot_file_menu[] =
 		N_("Preview the plot before printing"), NULL),
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_ITEM_NONE(N_("Export plot"),
-		N_(""), plot_export),
+		N_("Show the export menu"), plot_export),
 	GNOMEUIINFO_SEPARATOR,
 	GNOMEUIINFO_MENU_CLOSE_ITEM(destroy_window,NULL),
 	GNOMEUIINFO_END
@@ -217,11 +217,11 @@ gchar *tmp;
 	if (!strcmp (str, "voltage")) {
 		tmp = g_strdup ("Volt");
 	} else if (!strcmp (str, "time") ) {
-		tmp = g_strdup (_("s"));
+		tmp = g_strdup ("s");
 	} else if (!strcmp (str, "frequency") ) {
-		tmp = g_strdup (_("Hz"));
+		tmp = g_strdup ("Hz");
 	} else if (!strcmp (str, "current") ) {
-		tmp = g_strdup (_("A"));
+		tmp = g_strdup ("A");
 	} else {
 		tmp = g_strdup ("##");
 	}
@@ -304,7 +304,8 @@ analysis_selected (GtkEditable *editable, Plot *plot)
 
 	if (plot->current == NULL) {
 		/* Simulation failed? */
-		g_warning("No hay datos de la simulacion!!\n");
+		//g_warning("No hay datos de la simulacion!!\n");
+		g_warning (_("No data for the Simulation !!\n"));
 		return;
 	}
 
@@ -875,7 +876,7 @@ plot_export (GtkWidget *widget, Plot *plot)
 	GtkWidget *window;
 	GtkRadioButton *export_png, *export_ps;
 	GtkSpinButton *width, *height;
-
+	
 	if (!g_file_test (OREGANO_GLADEDIR "/plot-export.glade2", G_FILE_TEST_EXISTS)) {
 		msg = g_strdup_printf (
 			_("<span weight=\"bold\" size=\"x-large\">Could not find the required file:\n</span>%s\n"),
@@ -921,4 +922,3 @@ plot_export (GtkWidget *widget, Plot *plot)
 
 	gtk_widget_destroy (window);
 }
-
