@@ -10,7 +10,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2004  LUGFI
+ * Copyright (C) 2003,2005  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -337,7 +337,7 @@ print_schematic (GObject *w, gboolean preview_only)
 	if (paper_name) {
 		paper = gnome_print_paper_get_by_name (paper_name);
 		if (paper == NULL) {
-			g_warning (_("Can't get paper info! .. geting default!"));
+			g_warning (_("Can't get paper info! .. getting default!"));
 			paper = gnome_print_paper_get_default ();
 		}
 	} else {
