@@ -10,7 +10,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2004  LUGFI
+ * Copyright (C) 2003,2005  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -549,7 +549,8 @@ schematic_write_xml (Schematic *sm)
 	{
 		char *s =schematic_get_filename (sm);
 		if (s != NULL) {
-			ret = xmlSaveFile (s, xml);
+			xmlIndentTreeOutput;
+			ret = xmlSaveFormatFile (s, xml, 1);
 		} else {
 			g_warning("Schematic has no filename!!\n");
 		}
