@@ -56,7 +56,7 @@ static GnomeUIInfo schematic_menu_file [] = {
 	  N_("Print Preview"),
 	  N_("Preview the schematic before printing"),
 	  print_preview_cmd, NULL, NULL,
-	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PRINT,
+	  GNOME_APP_PIXMAP_STOCK, GTK_STOCK_PRINT_PREVIEW,
 	  0, 0, NULL },
 
 	GNOMEUIINFO_SEPARATOR,
