@@ -10,7 +10,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2004  LUGFI
+ * Copyright (C) 2003,2005  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -60,7 +60,7 @@
 #include "plot.h"
 #include "sheet-item-factory.h"
 #include "part-item.h"
-#include "netlist-editor.h"
+//#include "netlist-editor.h"
 #include "node-item.h"
 
 /* remove: */
@@ -384,7 +384,7 @@ open_cmd (GtkWidget *widget, SchematicView *sv)
 
 		gtk_widget_show_all (new_sv->toplevel);
 		schematic_set_filename (new_sm, fname);
-		// schematic_set_title (new_sm, fname);
+		schematic_set_title (new_sm, g_path_get_basename(fname));
 	}
 
 	g_free (fname);
@@ -2740,4 +2740,3 @@ schematic_view_get_page_properties (SchematicView *sv)
 {
 	return &(sv->priv->page);
 }
-
