@@ -10,7 +10,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2004  LUGFI
+ * Copyright (C) 2003,2005  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -547,7 +547,7 @@ schematic_read (char *name)
 	char *fname;
 	GError *error = NULL;
 
-	g_return_val_if_fail (fname != NULL, NULL);
+	g_return_val_if_fail (name != NULL, NULL);
 
 	fname = g_filename_from_uri  (name, NULL, &error);
 
