@@ -10,7 +10,7 @@
  * Web page: http://arrakis.lug.fi.uba.ar/
  *
  * Copyright (C) 1999-2001  Richard Hult
- * Copyright (C) 2003,2004  LUGFI
+ * Copyright (C) 2003,2005  LUGFI
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -293,7 +293,7 @@ sim_engine_start_with_file (SimEngine *engine, const gchar *netlist)
 		//setlocale (LC_NUMERIC, "C");
 
 		/* Execute Sim Engine. */
-		/* SimExec deberia apuntar a oregano_parser.pl con
+		/* SimExec deberia apuntar a oregano_parser con
 		 * path y todo
 		 */
 		execvp(simexec, args);
@@ -670,7 +670,7 @@ data_input_cb (SimEngine *engine, gint source, GdkInputCondition condition)
 			break;
 		}
 	} else {
-		if (engine->analysis == 0) {
+		if ((engine->analysis == 0) || (isalpha (buf[0]))) {
 			if (strlen (buf) > 1)
 				schematic_log_append (engine->sm, buf);
 			return;
