@@ -260,8 +260,8 @@ nl_create_analisys_string (NodeStore *store, gboolean do_ac)
 }
 
 
-void nl_generate_spice (net_out * , FILE *);
-void nl_generate_gnucap (net_out *, FILE *);
+void nl_generate_spice (net_out * , FILE *, NetlistData *data);
+void nl_generate_gnucap (net_out *, FILE *, NetlistData * data);
 
 gchar *
 nl_generate (Schematic *sm, gchar *fn, GError **error)
@@ -343,7 +343,7 @@ nl_generate (Schematic *sm, gchar *fn, GError **error)
 		g_set_error (error,
 			OREGANO_SIMULATE_ERROR,
 			OREGANO_SIMULATE_ERROR_NO_CLAMP,
-				_("Possibly dueto a faulty circuit schematic. Please check that\n"
+				_("Possibly due to a faulty circuit schematic. Please check that\n"
 					"you have one o more test clamps and try again.")
 			);
 
@@ -505,11 +505,10 @@ nl_generate (Schematic *sm, gchar *fn, GError **error)
 	}
 	g_free (node2real);
 
-
 	if (strcmp (oregano.simtype,"gnucap") == 0 )
-		nl_generate_gnucap (&out, f);
+		nl_generate_gnucap (&out, f, data);
 	else if (strcmp (oregano.simtype,"ngspice") == 0)
-		nl_generate_spice (&out, f);
+		nl_generate_spice (&out, f, data);
 	else
 		printf ("Simulator %s is not avaible.", oregano.simtype );
 	fclose (f);
@@ -530,7 +529,7 @@ nl_generate (Schematic *sm, gchar *fn, GError **error)
 }
 
 
-void nl_generate_spice (net_out * output, FILE *file)
+void nl_generate_spice (net_out * output, FILE *file, NetlistData * data)
 {
 
 	GList *list = sim_settings_get_options (output->settings);
@@ -556,6 +555,9 @@ void nl_generate_spice (net_out * output, FILE *file)
 		}
 		list = list->next;
 	}
+		
+	/* Inclusion of complex part */
+	g_hash_table_foreach (data->models, (GHFunc) foreach_model_write, file);
 
 	/* Prints template parts */
 
@@ -609,7 +611,7 @@ void nl_generate_spice (net_out * output, FILE *file)
 	fputs ("\n.end\n", file);
 }
 
-void nl_generate_gnucap (net_out * output, FILE *file)
+void nl_generate_gnucap (net_out * output, FILE *file, NetlistData * data)
 {
 	GList *list = sim_settings_get_options ( output->settings );
 	SimOption *so;
@@ -639,6 +641,10 @@ void nl_generate_gnucap (net_out * output, FILE *file)
 	fputc ('\n',file);
 	/* Prints template parts */
 
+	/* Inclusion of complex part */
+	/* TODO : add GNU Cap model inclusion */
+	/* g_hash_table_foreach (data->models, (GHFunc) foreach_model_write_gnucap, file); */
+
 	fputs ("*----------------------------------------------\n",file);
 	fputs (output->template->str,file);
 	fputs ("*----------------------------------------------\n",file);
